@@ -1,7 +1,7 @@
 from pathlib import Path
 
-from tomlkit.toml_document import TOMLDocument
-from tomlkit.toml_file import TOMLFile
+from atoml.toml_document import TOMLDocument
+from atoml.toml_file import TOMLFile
 
 
 class ConfigError(Exception):
@@ -27,6 +27,6 @@ def parse(config_file: Path) -> TOMLDocument:
         raise RuntimeError(f'Configuration file {config_file} not found.')
 
     try:
-        return TOMLFile(path).read()
+        return TOMLFile(str(path)).read()
     except Exception as exc:
         raise ConfigError(f'Failed to parse {config_file}') from exc
